pilas.actores.dialogo.Dialogo

Package pilas :: Package actores :: Module dialogo :: Class Dialogo |
[hide private]
[frames] | no frames]

# Class Dialogo

source code

Representa una secuencia de mensajes entre varios actores.

    >>> mono = pilas.actores.Mono()
    >>> mono2 = pilas.actores.Mono()
    >>> dialogo = pilas.actores.Dialogo()
    >>> dialogo.decir(mono, "Hola Mundo")
    >>> dialogo.decir(mono2, "Estoy diciendo algo")
    >>> dialogo.iniciar()

.. image:: images/actores/mono_dice.png

Instance Methods | [hide private]
__init__(self, modo_automatico=True) Constructor del Diálogo | source code
decir(self, actor, texto) Añade un texto a la conversación y establece el actor que lo dice. | source code
decir_inmediatamente(self, actor, texto) Muestra un texto de dialogo inmediatamente sin seguir una secuencia de dialogo. | source code
elegir(self, actor, texto, opciones, funcion_a_invocar) Muestra un texto de dialogo con una lista de opciones para poder seleccionar y ejecutar una accion cuando se seleccione una de las opciones del cuadro de dialogo. | source code
ejecutar(self, funcion) | source code
iniciar(self) Inicia el dialogo que se haya definido. | source code
obtener_siguiente_dialogo_o_funcion(self) | source code
_eliminar_dialogo_actual(self) | source code
_mostrar_o_ejecutar_siguiente(self, siguiente) | source code
avanzar_al_siguiente_dialogo(self, evento=None) | source code

Method Details | [hide private]

### __init__(self, modo_automatico=True) (Constructor) | source code
Constructor del Diálogo :param modo_automatico: Establece si el dialogo ira cambiando automatiamente. :type modo_automatico: boolean

### decir(self, actor, texto) | source code
Añade un texto a la conversación y establece el actor que lo dice. :param actor: Actor que dirá el texto. :type actor: Actor :param texto: Texto que dirá el actor. :type texto: string

### decir_inmediatamente(self, actor, texto) | source code
Muestra un texto de dialogo inmediatamente sin seguir una secuencia de dialogo. :param actor: Actor que dirá el texto. :type actor: Actor :param texto: Texto que dirá el actor. :type texto: string

### elegir(self, actor, texto, opciones, funcion_a_invocar) | source code
Muestra un texto de dialogo con una lista de opciones para poder seleccionar y ejecutar una accion cuando se seleccione una de las opciones del cuadro de dialogo. :param actor: Actor que dirá el texto. :type actor: Actor :param texto: Texto que aparecerá en la parte superior del dialogo de opciones. :type texto: string :param opciones: Array de posibles opciones que mostrará el cuadrio de dialogo. :type opciones: Array :param funcion_a_invocar: Método al que se llamará cuando se seleccione una de las opciones del listado. Este metodo recibirá como parámetro la opción que se haya seleccinado.
    >>> def cuando_responde_color_favorito(respuesta):
    >>>    colores = {
    >>>               'rojo': pilas.colores.rojo,
    >>>               'verde': pilas.colores.verde,
    >>>               'azul': pilas.colores.azul,
    >>>              }
    >>>
    >>>    pilas.fondos.Color(colores[respuesta])
    >>>    mono.sonreir()
    >>>    d.decir(mono, '¡mira!')
    >>>
    >>> d.elegir(mono_chiquito, 'Mi color favorito es el...', ['rojo', 'verde', 'azul'], cuando_responde_color_favorito)

### iniciar(self) | source code
Inicia el dialogo que se haya definido.
    >>> d = pilas.actores.Dialogo()
    >>> d.decir(mono, "¿Cual es tu color favorito?")
    >>> d.iniciar()